@@ -87,7 +87,7 @@ class GenericOmnibarView(View):
 # LIST {{{1
 class GenericListView(PermissionRequiredMixin, ListView):
     template_name = 'genviews/list.html'
-    template_list_name = 'genviews/list_tpl.html'
+    template_list_name = 'genviews/table.html'
     list_cls = 'generic-list'
     fields = '__all__' 
 
